pub struct ErfcOperation<'c> { /* private fields */ }Expand description
An erfc operation. Complementary error function of the specified value.
The erfc operation computes the complementary error function, defined as
1-erf(x). This function is part of libm and is needed for accuracy, since
simply calculating 1-erf(x) when x is close to 1 will give inaccurate results.
It takes one operand of floating point type (i.e., scalar,
tensor or vector) and returns one result of the same type. It has no
standard attributes.
Example:
// Scalar error function value.
%a = math.erfc %b : f64Implementations
Sourceimpl<'c> ErfcOperation<'c>
impl<'c> ErfcOperation<'c>
Sourcepub fn as_operation(&self) -> &Operation<'c>
pub fn as_operation(&self) -> &Operation<'c>
Returns a generic operation.
Sourcepub fn builder(
context: &'c Context,
location: Location<'c>,
) -> ErfcOperationBuilder<'c, Unset>
pub fn builder( context: &'c Context, location: Location<'c>, ) -> ErfcOperationBuilder<'c, Unset>
Creates a builder.
pub fn result(&self) -> Result<OperationResult<'c, '_>, Error>
pub fn operand(&self) -> Result<Value<'c, '_>, Error>
pub fn fastmath(&self) -> Result<Attribute<'c>, Error>
pub fn set_fastmath(&mut self, value: Attribute<'c>)
pub fn remove_fastmath(&mut self) -> Result<(), Error>